##  Calling API Endpoints from Scripts
You can configure scripts that make calls to SAP LeanIX APIs. This lets you configure complex automation scenarios without relying on third-party solutions. Code runs securely within the SAP LeanIX environment. To learn more about available APIs, see [SAP LeanIX APIs](https://help.sap.com/docs/leanix/ea/sap-leanix-apis?locale=en-US&state=PRODUCTION&version=CLOUD "Explore SAP LeanIX APIs and learn when to use each API.").
For example, you can initiate the following actions from scripts based on changes in fact sheet data:
  * Retrieve or update fact sheet data.
  * Create to-dos to assign tasks to users.
  * Start survey runs to collect information from multiple users.


To view example automations with scripts that call APIs, see:
  * [Synchronizing Subscriptions Across Related Fact Sheets (Subscription Inheritance)](https://help.sap.com/docs/leanix/ea/synchronizing-subscriptions-across-related-fact-sheets-subscription-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD "Configure automations with scripts to automatically synchronize subscriptions across related fact sheets.")
  * [Breaking Application Quality Seals when Initiatives Reach End of Life](https://help.sap.com/docs/leanix/ea/breaking-application-quality-seals-when-initiatives-reach-end-of-life?locale=en-US&state=PRODUCTION&version=CLOUD "Configure automations with scripts to automatically break quality seals on applications when related initiatives reach End of Life.")
  * [Propagating Business Context Relations to Parent Applications (Relation Inheritance)](https://help.sap.com/docs/leanix/ea/propagating-business-context-relations-to-parent-applications-relation-inheritance?locale=en-US&state=PRODUCTION&version=CLOUD "Configure automations with scripts to automatically propagate relations from business contexts to parent applications.")
